A Python package for changing text colors in the terminal, perfect for adding a pop of color to your command-line applications!

*Features*

- Change text colors to brighten up your terminal output
- Change text's background color

*Example Usage*
    from paintxt import Colors

    print(Colors.RED+"Hello, World!")  # Print "Hello, World!" in red
    print(Colors.BG_WHITE+"Hello, World!")  # Print "Hello, World!" with a red background
    print(Colors.colors) # Print all available colors